/*
 * Copyright (c) 2014 Patrick P. Frey
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
/// \brief Exported functions of the strus analyzer library
/// \file analyzer.hpp
#ifndef _STRUS_ANALYZER_LIB_HPP_INCLUDED
#define _STRUS_ANALYZER_LIB_HPP_INCLUDED
#include "strus/analyzer/segmenterOptions.hpp"
#include <string>

/// \brief strus toplevel namespace
namespace strus {

/// \brief Forward declaration
class DocumentAnalyzerInterface;
/// \brief Forward declaration
class QueryAnalyzerInterface;
/// \brief Forward declaration
class SegmenterInterface;
/// \brief Forward declaration
class TextProcessorInterface;
/// \brief Forward declaration
class ErrorBufferInterface;

/// \brief Creates a parameterizable analyzer instance for analyzing documents
/// \param[in] segmenter segmenter type to be used by the created analyzer.
/// \return the analyzer program (with ownership)
DocumentAnalyzerInterface* createDocumentAnalyzer( const TextProcessorInterface* textproc, const SegmenterInterface* segmenter, const analyzer::SegmenterOptions& opts, ErrorBufferInterface* errorhnd);

/// \brief Creates a parameterizable analyzer instance for analyzing queries
/// \return the analyzer program (with ownership)
QueryAnalyzerInterface* createQueryAnalyzer( ErrorBufferInterface* errorhnd);

}//namespace
#endif

